@@ -12,6 +12,7 @@ CREATE FUNCTION @extschema@.undo_partition(
 )
     RETURNS record
     LANGUAGE plpgsql
+    SET search_path = @extschema@, pg_catalog, pg_temp
     AS $$
 DECLARE
 
@@ -131,19 +132,16 @@ ELSE
     RAISE EXCEPTION 'Data type of control column in given partition set must be either date/time or integer.';
 END IF;
 
-SELECT current_setting('search_path') INTO v_old_search_path;
-IF length(v_old_search_path) > 0 THEN
-   v_new_search_path := '@extschema@,pg_temp,'||v_old_search_path;
-ELSE
-    v_new_search_path := '@extschema@,pg_temp';
-END IF;
 IF v_jobmon THEN
     SELECT nspname INTO v_jobmon_schema FROM pg_catalog.pg_namespace n, pg_catalog.pg_extension e WHERE e.extname = 'pg_jobmon'::name AND e.extnamespace = n.oid;
     IF v_jobmon_schema IS NOT NULL THEN
-        v_new_search_path := format('%s,%s',v_jobmon_schema, v_new_search_path);
+        SELECT current_setting('search_path') INTO v_old_search_path;
+        IF v_jobmon_schema IS NOT NULL THEN
+            v_new_search_path := format('%s,%s',v_jobmon_schema, v_old_search_path);
+            EXECUTE format('SET LOCAL search_path TO %s', v_new_search_path);
+        END IF;
     END IF;
 END IF;
-EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_new_search_path, 'false');
 
 -- Check if any child tables are themselves partitioned or part of an inheritance tree. Prevent undo at this level if so.
 -- Need to lock child tables at all levels before multi-level undo can be performed safely.
@@ -334,7 +332,7 @@ LOOP
                     , v_child_min_time + (v_batch_interval_time * v_inner_loop_count)
                     , v_column_list
                     , v_target_schema
-                    , v_target_tablename);            
+                    , v_target_tablename);
             ELSIF (v_control_type IN ('text', 'uuid')) THEN
                 EXECUTE format('WITH move_data AS (
                                         DELETE FROM %I.%I WHERE %s <= %s(%L) RETURNING %s )
@@ -360,7 +358,7 @@ LOOP
             v_batch_loop_count := v_batch_loop_count + 1;
 
             -- Check again if table is empty and go to outer loop again to drop it if so
-            
+
             IF v_control_type = 'time' OR (v_control_type = 'id' AND v_epoch <> 'none') THEN
                 EXECUTE format('SELECT min(%s) FROM %I.%I', v_partition_expression, v_parent_schema, v_child_table) INTO v_child_min_time;
             ELSIF (v_control_type IN ('text', 'uuid')) THEN
@@ -464,8 +462,6 @@ IF v_jobmon_schema IS NOT NULL THEN
     PERFORM close_job(v_job_id);
 END IF;
 
-EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_old_search_path, 'false');
-
 partitions_undone := v_undo_count;
 rows_undone := v_total;
 
